@@ -2,4 +2,4 @@
 
 ASTRO_API_BASE_URL_ENV_VAR = "ASTRO_API_BASE_URL"
 ORGANIZATION_ID_ENV_VAR = "ASTRO_ORGANIZATION_ID"
-TOKEN_ENV_VAR = "AIRFLOW_VAR_AUTH_TOKEN"
+TOKEN_ENV_VAR = "OBSERVE_API_TOKEN"
